require 'questionable/version'

require 'active_record'

module Questionable
    module ActsAsQuestionable
        extend ActiveSupport::Concern

        included do
            has_many :questions, class_name: 'Questionable::Question', dependent: :destroy
        end
    end

    class Question < ActiveRecord::Base
        belongs_to :questionable, polymorphic: true
        has_many :answers, class_name: 'Questionable::Answer', dependent: :destroy

        validates :subject, presence: true
    end

    class Answer < ActiveRecord::Base
        belongs_to :question, class_name: 'Questionable::Question'

        validates :text, presence: true
    end

    # module ClassMethods
    #     def acts_as_questionable
    #         base.include ActsAsQuestionable
    #     end
    # end

    module Generators
        class InstallGenerator < ::Rails::Generators::Base
            include Rails::Generators::Migration

            source_root File.expand_path('../templates', __FILE__)

            def copy_migrations
                filename = 'questionable_migration'

                if self.class.migration_exists?('db/migrate', filename)
                    say_status('skipped', "Migration #{filename}.rb already exists")
                else
                    migration_template "migrations/#{filename}.rb", "db/migrate/#{filename}.rb"
                end
            end
        end
    end
end

ActiveRecord::Base.send :include, Questionable::ActsAsQuestionable
